/*
 * main.c
 *
 *  Created on: 26 juin 2011
 *      Author: Maxime
 *
#include "avr_compiler.h"
#include <avr/io.h>
#include "port_driver.h"
#include "clksys_driver.h"

int main(void)
{
	unsigned int i=0;	//Variables ce comptage (de 0  65535)

	//Oscillateur  8MHz
	CLKSYS_XOSC_Config( OSC_FRQRANGE_2TO9_gc, false, OSC_XOSCSEL_XTAL_256CLK_gc );		//Selectionne un crystal de 2  9MHz
	CLKSYS_Enable( OSC_XOSCEN_bm );	//Active l'oscillateur externe
	do {} while ( CLKSYS_IsReady( OSC_XOSCRDY_bm ) == 0 );	//wait for a stable osc.
	CLKSYS_Main_ClockSource_Select( CLK_SCLKSEL_XOSC_gc );	//switch intern to extern clock source
	CLKSYS_Disable( OSC_RC32MEN_bm );	//disable the internal osc.

	//Configuration de la patte de la LED en sortie
	PORT_SetDirection(&PORTQ,0b00000100);	//La LED est branche sur la patte 2 du PORTQ
	PORT_SetPins(&PORTQ, 0b00000000);

	//Boucle infinie
	while(1)
	{
		//On change l'tat de la LED(allum devient teind et inversement)
		PORT_SetPins(&PORTQ,0b00000100);
		for(i=0;i<50000;i++);
		PORT_ClearPins(&PORTQ, 0b00000100);
		for(i=0;i<50000;i++);
	}
}*/
/********************************************************************************************************************************************************
 * 																																						*
 * 									PROGRAMME DE GESTION DE LA PINCE DE SCHBENER - CRIS 2011															*
 * 																																						*
 ********************************************************************************************************************************************************/

#include <avr/io.h>
#include <math.h>

#include "avr_compiler.h"
#include "clksys_driver.h"
#include "pmic_driver.h"
#include "port_driver.h"
#include "TC_driver.h"

//La LED de la platine est sur PQ2
#define Set_LEDPlatine_OFF()		PORT_SetOutputBit(&PORTQ,2)
#define Set_LEDPlatine_ON()			PORT_ClearOutputBit(&PORTQ,2)
#define LED_Platine_Toggle()		PORT_TogglePins(&PORTQ,0b00000100)

/************************************
*			LOCAL DEFINES			*
*************************************/
#define PERIODE_REGUL_COURANT	1
#define PERIODE_COM_DEBUG		250

/************************************
*			GLOBAL VARIABLES		*
*************************************/

volatile unsigned long globalTime = 0;
volatile unsigned long ledTime = 0;

/************************************
 * 		 INTERRUPTIONS				*
 ************************************/
//Interruption correspondant  l'appui sur le bouton
//Si la pince ne doit pas aller en bas, elle ira.
//Sinon elle monte  sa position max.
ISR(PORTQ_INT0_vect)
{
	LED_Platine_Toggle();
}

//Incrmente globalTime toute les millisecondes.
ISR(TCC0_OVF_vect)
{
	globalTime++;
}

/************************************
 * 				MAIN				*
 ************************************/
int main(void)
{

	//unsigned char debug = 0;

	//Oscillateur  8MHz
	CLKSYS_XOSC_Config( OSC_FRQRANGE_2TO9_gc, false, OSC_XOSCSEL_XTAL_256CLK_gc );		//Selectionne un crystal de 2  9MHz
	CLKSYS_Enable( OSC_XOSCEN_bm );	//Active l'oscillateur externe
	do {} while ( CLKSYS_IsReady( OSC_XOSCRDY_bm ) == 0 );	//wait for a stable osc.
	CLKSYS_Main_ClockSource_Select( CLK_SCLKSEL_XOSC_gc );	//switch intern to extern clock source
	CLKSYS_Disable( OSC_RC32MEN_bm );	//disable the internal osc.

	//Interruption lors de l'appuit sur le bouton
	PORT_SetDirection(&PORTQ,0b00000100);
	PORT_ConfigurePins(&PORTQ,0b00001000,false,false,PORT_OPC_TOTEM_gc,PORT_ISC_FALLING_gc);
	PORT_ConfigureInterrupt0(&PORTQ, PORT_INT0LVL_MED_gc, 0b00001000);

	//Timer0C pour la base de temps globalTime de 1ms.
	TC_SetPeriod(&TCC0,1000);
	TC0_ConfigClockSource(&TCC0,TC_CLKSEL_DIV8_gc);
	TC0_SetOverflowIntLevel(&TCC0,TC_OVFINTLVL_MED_gc);



	//Activation des interruptions
	PMIC_EnableLowLevel();
	PMIC_EnableMediumLevel();
	PMIC_EnableHighLevel();
	sei();

/************************************
 * 		   BOUCLE INFINIE			*
 ************************************/

	for(;;)
	{
		if((globalTime - ledTime)>1000)
		{
			LED_Platine_Toggle();
			ledTime = globalTime;
			//Essui-glace avec un servo
			//if(debug==0){setConsigneServoAvantDroit(SERVO_AVANT_D_FERME); debug = 1;}else{setConsigneServoAvantDroit(SERVO_AVANT_D_OUVERT);	debug = 0;}
		}
	}
}

